@@ -46,6 +46,9 @@ pub struct Widget<'a> {
     /// The widget's layout properties for grids.
     #[serde(default)]
     pub layout: HashMap<Cow<'a, str>, Property<'a>>,
+    /// Any addition xml you wish to use.
+    #[serde(default)]
+    pub xml: Option<Cow<'a, str>>,
 }
 
 impl Display for Widget<'_> {
@@ -97,6 +100,10 @@ impl Display for Widget<'_> {
         for child in &*self.children {
             write!(f, "{}", child)?;
         }
+
+        if let Some(xml) = &self.xml {
+            write!(f, "{}", xml)?;
+        }
         
         write!(f, "</object>")
     }
